aboutsummaryrefslogtreecommitdiff
path: root/gdb/printcmd.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/printcmd.c')
-rw-r--r--gdb/printcmd.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gdb/printcmd.c b/gdb/printcmd.c
index e156d84..6da10aa 100644
--- a/gdb/printcmd.c
+++ b/gdb/printcmd.c
@@ -212,14 +212,14 @@ decode_format (char **string_ptr, int oformat, int osize)
case 'a':
case 's':
/* Pick the appropriate size for an address. */
- if (TARGET_PTR_BIT == 64)
+ if (gdbarch_ptr_bit (current_gdbarch) == 64)
val.size = osize ? 'g' : osize;
- else if (TARGET_PTR_BIT == 32)
+ else if (gdbarch_ptr_bit (current_gdbarch) == 32)
val.size = osize ? 'w' : osize;
- else if (TARGET_PTR_BIT == 16)
+ else if (gdbarch_ptr_bit (current_gdbarch) == 16)
val.size = osize ? 'h' : osize;
else
/* Bad value for TARGET_PTR_BIT. */
internal_error (__FILE__, __LINE__,
_("failed internal consistency check"));
break;
@@ -212,14 +212,14 @@ decode_format (char **string_ptr, int oformat, int osize)
val.size = osize ? 'h' : osize;
else
- /* Bad value for TARGET_PTR_BIT. */
+ /* Bad value for gdbarch_ptr_bit. */
internal_error (__FILE__, __LINE__,
_("failed internal consistency check"));